SherpaInitCommand class final

Initializes the ONNX Zipformer CTC streaming engine with model and token asset paths.

Inheritance

Constructors

SherpaInitCommand({required String modelPath, required String tokensPath})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
modelPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokensPath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited