SherpaRecognizeCommand class final

Transcribes a raw 16kHz float32 audio chunk.

Inheritance

Constructors

SherpaRecognizeCommand({required TransferableTypedData chunk, required bool isFinal, required int startTime})
const

Properties

chunk TransferableTypedData
final
hashCode int
The hash code for this object.
no setterinherited
isFinal bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited