ErrorExplainer class

Constructors

ErrorExplainer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

evaluatePreAlignedWords({required List<PhonemeGroupAlignment> alignments, required String fullPhonemes, required List<int> wordBoundaries, required String currentAsrText, required List<double> trackingTimestamps, required int bestAsrStartIdx, required int targetCharCursor, required int startWordId, required int nextWordId, required int totalAyahWords, List<WordTajweedRule> expectedWordRules = const [], TrackerConfig config = const TrackerConfig()}) Map<int, List<ReciterError>>
Evaluates pre-aligned phoneme traces for a specific committed word window.