PhonemeGroupAlignment class

Represents the alignment opcode between a single reference phoneme group and predicted phoneme group.

Constructors

PhonemeGroupAlignment({required String opType, required int refIdx, required int predIdx})

Properties

hashCode int
The hash code for this object.
no setterinherited
opType String
final
predIdx int
final
refIdx int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited