AsrTokenProcessor class

Constructors

AsrTokenProcessor({TrackerConfig config = const TrackerConfig()})

Properties

config TrackerConfig
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lookaheadDelay double
no setter
maxTokenDuration double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(TranscriptionResult result) ProcessedAudioStream
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited