ProcessedAudioStream class

Constructors

ProcessedAudioStream({required List<String> tokens, required List<double> durations})

Properties

durations List<double>
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokens List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited