SyncStreamCommand class

Inheritance

Constructors

SyncStreamCommand({required String asrText, required List<double> timestamps, bool isNewSegment = false, int ayahNumber = 0})
const

Properties

asrText String
final
ayahNumber int
final
hashCode int
The hash code for this object.
no setterinherited
isNewSegment bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamps List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited