DebugLogger class

Constructors

DebugLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

log(String tag, String message) → void
Central logging method with structured AI-readable layout.
logSimple(String tag, String message) → void
Simple log for things that don't need the ASR buffer context attached.
updateAsrBuffer(String buffer) → void
Updates the cached ASR buffer that will be appended to detailed logs.