updateAsrBuffer static method
Updates the cached ASR buffer that will be appended to detailed logs.
Implementation
static void updateAsrBuffer(String buffer) {
_currentAsrBuffer = buffer;
}
Updates the cached ASR buffer that will be appended to detailed logs.
static void updateAsrBuffer(String buffer) {
_currentAsrBuffer = buffer;
}