AudioProcessor class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearBuffer(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
{required void onChunk(Float32List chunk, bool isFinal)}) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bytesPerSample → const int
- chunkMs → const int
- numChannels → const int
- recordChunkBytes → const int
- recordSampleRate → const int
- The sample rate that the ASR model and VAD expect.