ContinuousQuranWord class
Constructors
-
ContinuousQuranWord({required int globalIndex, required int surah, required int ayah, required int wordInAyah, required String uthmani, required String phoneme, List<
WordTajweedRule> rules = const []}) -
const
Properties
- ayah → int
-
final
- globalIndex → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneme → String
-
final
-
rules
→ List<
WordTajweedRule> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surah → int
-
final
- uthmani → String
-
final
- wordInAyah → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited