QuranRepository class
Constructors
- QuranRepository(QuranMetadataService _service)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
surahMetadata
→ List<
QuranVerse> -
no setter
Methods
-
getAyahStartGlobalIndex(
int surah, int ayah) → int -
getNextVerse(
int surah, int ayah) → QuranVerse? -
getSurah(
int surah) → List< QuranVerse> -
getSurahWords(
int surah) → List< ContinuousQuranWord> -
getVerse(
int surah, int ayah) → QuranVerse? -
loadSurahAsync(
int surah) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited