SherpaEngine class
Web-specific implementation of SherpaEngine using Official Sherpa WebAssembly JS.
Constructors
Properties
- currentStreamEpoch → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transcriptionStream
→ Stream<
TranscriptionResult> -
no setter
Methods
-
destroy(
) → void -
flushThenReset(
) → void -
initialize(
) → Future< void> -
isModelCached(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preExtractAssets(
) → Future< void> -
resetBuffer(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
transcribe(
Float32List audioChunk, {bool isFinal = false}) → bool
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited