ErrorCategory enum
Broad classification of reciter errors used by UI color highlighting and statistics.
Values
- tajweed → const ErrorCategory
-
Acoustic duration or Shaddah doubling mismatch (
Yellow highlight). - normal → const ErrorCategory
-
Base letter replacement, total deletion, or insertion (
Red highlight). - tashkeel → const ErrorCategory
-
Same base consonant but incorrect diacritics/vowels (
Yellow highlight).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ErrorCategory> - A constant List of the values in this enum, in order of their declaration.