PhonemeGroupAlignment class
Represents the alignment opcode between a single reference phoneme group and predicted phoneme group.
Constructors
- PhonemeGroupAlignment({required String opType, required int refIdx, required int predIdx})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited