ReciterError class
Immutable diagnostic record detailing a detected recitation mismatch.
Constructors
- ReciterError({required ErrorCategory errorType, required SpeechErrorType speechErrorType, TajweedDurationStatus? durationStatus, required String expectedPh, required String predictedPh, TajweedRule? expectedRule, TajweedRule? predictedRule, double? expectedDuration, double? actualDuration})
Properties
- actualDuration → double?
-
final
- durationStatus → TajweedDurationStatus?
-
final
- errorType → ErrorCategory
-
final
- expectedDuration → double?
-
final
- expectedPh → String
-
final
- expectedRule → TajweedRule?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- predictedPh → String
-
final
- predictedRule → TajweedRule?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speechErrorType → SpeechErrorType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMap(
Map< String, dynamic> map) → ReciterError