SetSurahReferenceCommand class
- Inheritance
-
- Object
- IsolateCommand
- SetSurahReferenceCommand
Constructors
Properties
-
boundaries
→ List<
int> -
final
- forceClear → bool
-
final
- fullPhonemes → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTajweed → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startGlobalWord → int
-
final
- surahNumber → int
-
final
-
wordRules
→ List<
List< ?WordTajweedRule> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited